@@ -211,10 +211,10 @@ class NxPyDocs():
 def cli(command,
         filetype,
         ):
-    invoke_class = nxpydocs(command,
+    invoke_class = NxPyDocs(command,
                             filetype,
                         )
-    invoke_class.print_json()
+    invoke_class.abortion_policies()
 
 if __name__ == "__main__":
     cli()
